<?php
/**
 * info section
 *
 * This is the template for the content of info section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_info_section' ) ) :
  /**
   * Add info section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_info_section() {

    // Check if info is enabled on frontpage
    $info_enable = apply_filters( 'kids_education_pro_section_status', true, 'enable_info_content' );
    if ( true !== $info_enable ) {
      return false;
    }

    // Get info section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_info_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render info section now.
    kids_education_pro_render_info_section( $section_details );
  }
endif;
add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_info_section', 20 );


if ( ! function_exists( 'kids_education_pro_get_info_section_details' ) ) :
  /**
   * info section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input info section details.
   */
  function kids_education_pro_get_info_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();
    // info type
    $info_content_type  = $options['info_content_type'];

    $content = array();
    switch ( $info_content_type ) {
        case 'demo':
          $content['headline']       = esc_html__( 'Find a Babysitter for your Kids during the holidays so you can shop, attend parties and wrap presents!', 'kids-education-pro' );
          $content['url']            = '#';
          $content['read_more_text'] = esc_html__( 'Read More', 'kids-education-pro' );

        break;

        case 'page':
          $id = null;
          if ( isset( $options[ 'info_content_page_id' ] ) ) {
              $id = $options[ 'info_content_page_id' ];
          }
          if ( ! empty( $id ) ) {
              $id = absint( $id );
          }
          // Bail if no valid pages are selected.
          if ( empty( $id ) ) {
              return $input;
          }

          $args = array(
              'post_type'      => 'page',
              'p'              => $id,
          );
        break;

        default:
        break;
    }
    if ( 'demo' != $info_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          foreach ( $posts as $key => $post ) {
            $page_id = $post->ID;

            $content['url']            = get_permalink( $page_id );
            $content['headline']       = ( 'info_content_headline_from_title' == $options['info_content_heading_type'] ) ? get_the_title( $page_id ) : kids_education_pro_trim_content( 15, $post  );
            $content['read_more_text'] = $options['info_content_learn_more_text'];
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// info section content details.
add_filter( 'kids_education_pro_filter_info_section_details', 'kids_education_pro_get_info_section_details' );


if ( ! function_exists( 'kids_education_pro_render_info_section' ) ) :
  /**
   * Start info section
   *
   * @return string info content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_info_section( $content_details = array() ) {
        $options          = kids_education_pro_get_theme_options();
        
        $background_property = $options['info_content_background_property'];
        $background_css      = !empty( $options['info_content_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['info_content_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['info_content_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['info_content_background_color'] ) .'"' : '';
        }

        if ( empty( $content_details ) ) {
          return;
        } ?>
        <section id="info-text" class="page-section no-padding-bottom move-section-up background-image-properties" <?php echo $background_css; ?> >
            <div class="container">
                <div class="entry-content os-animation" data-os-animation="fadeIn">
                <?php if( !empty( $content_details['headline'] ) ) :?>
                    <h5><?php echo esc_html( $content_details['headline'] );?></h5>
                <?php endif; ?>
                <?php if( !empty( $content_details['read_more_text'] ) ) : ?>
                    <a href="<?php echo esc_url( $content_details['url'] ); ?>" class="btn btn-default"><?php echo esc_html( $content_details['read_more_text'] );?></a>
                <?php endif; ?>
                </div><!-- .entry-content -->
            </div><!-- .container -->
        </section><!-- #info-text -->
<?php 
    }
endif;